@@ -1,9 +1,9 @@
 from typing import Any, Dict, List, Optional
-from dataclasses import asdict, dataclass, field
+from dataclasses import asdict
 import time
 from datetime import datetime, timezone
 
-from ..core.base import BaseProcessor, ProcessingContext, ProcessingResult, ConfigProtocol
+from ..core.base import BaseProcessor, ProcessingContext, ProcessingResult, ConfigProtocol, ResultFormat
 from ..utils import (
     filter_by_confidence,
     filter_by_categories,
@@ -16,22 +16,33 @@ from ..utils import (
     BBoxSmoothingConfig,
     BBoxSmoothingTracker
 )
-from ..core.config import BaseConfig, AlertConfig
+from dataclasses import dataclass, field
+from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
 @dataclass
 class VehicleMonitoringConfig(BaseConfig):
-    """Configuration for vehicle monitoring use case."""
+    """Configuration for vehicle detection use case."""
     enable_smoothing: bool = True
     smoothing_algorithm: str = "observability"
     smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
     smoothing_confidence_range_factor: float = 0.5
-    confidence_threshold: float = 0.9
-    vehicle_categories: List[str] = field(
-        default_factory=lambda: ['bicycle', 'car', 'motorbike', 'auto rickshaw', 'bus', 'garbagevan', 'truck', 'minibus', 'army vehicle', 'pickup', 'policecar', 'rickshaw', 'scooter', 'suv', 'taxi', 'three wheelers -CNG-', 'human hauler', 'van', 'wheelbarrow']
+    confidence_threshold: float = 0.6
+    usecase_categories: List[str] = field(
+        default_factory=lambda: [
+            "bicycle", "car", "motorbike", "auto rickshaw", "bus", "garbagevan",
+            "truck", "minibus", "army vehicle", "pickup", "policecar", "rickshaw",
+            "scooter", "suv", "taxi", "three wheelers -CNG-", "human hauler",
+            "van", "wheelbarrow"
+        ]
     )
-    target_vehicle_categories: List[str] = field(
-        default_factory=lambda: ['car', 'bicycle', 'bus', 'garbagevan', 'truck', 'motorbike', 'van']
+    target_categories: List[str] = field(
+        default_factory=lambda: [
+            "bicycle", "car", "motorbike", "auto rickshaw", "bus", "garbagevan",
+            "truck", "minibus", "army vehicle", "pickup", "policecar", "rickshaw",
+            "scooter", "suv", "taxi", "three wheelers -CNG-", "human hauler",
+            "van", "wheelbarrow"
+        ]
     )
     alert_config: Optional[AlertConfig] = None
     index_to_category: Optional[Dict[int, str]] = field(
@@ -86,7 +97,12 @@ class VehicleMonitoringUseCase(BaseProcessor):
         self.category = "traffic"
         self.CASE_TYPE: Optional[str] = 'vehicle_monitoring'
         self.CASE_VERSION: Optional[str] = '1.0'
-        self.target_categories = ['car', 'bicycle', 'bus', 'garbagevan', 'truck', 'motorbike', 'van']
+        self.target_categories = [
+            "bicycle", "car", "motorbike", "auto rickshaw", "bus", "garbagevan",
+            "truck", "minibus", "army vehicle", "pickup", "policecar", "rickshaw",
+            "scooter", "suv", "taxi", "three wheelers -CNG-", "human hauler",
+            "van", "wheelbarrow"
+        ]
         self.smoothing_tracker = None
         self.tracker = None
         self._total_frame_counter = 0
@@ -116,13 +132,13 @@ class VehicleMonitoringUseCase(BaseProcessor):
             self.logger.debug(f"Applied confidence filtering with threshold {config.confidence_threshold}")
         else:
             processed_data = data
-            self.logger.debug("Did not apply confidence filtering")
+            self.logger.debug("Did not apply confidence filtering since no threshold provided")
 
         if config.index_to_category:
             processed_data = apply_category_mapping(processed_data, config.index_to_category)
             self.logger.debug("Applied category mapping")
 
-        if config.target_vehicle_categories:
+        if config.target_categories:
             processed_data = [d for d in processed_data if d.get('category') in self.target_categories]
             self.logger.debug("Applied category filtering")
 
@@ -229,16 +245,18 @@ class VehicleMonitoringUseCase(BaseProcessor):
                         "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']),
                                                         getattr(config.alert_config, 'alert_value', ['JSON']))}
                     })
-                elif category in per_category_count and per_category_count[category] > threshold:
-                    alerts.append({
-                        "alert_type": getattr(config.alert_config, 'alert_type', ['Default']),
-                        "alert_id": f"alert_{category}_{frame_key}",
-                        "incident_category": self.CASE_TYPE,
-                        "threshold_level": threshold,
-                        "ascending": get_trend(self._ascending_alert_list, lookback=900, threshold=0.8),
-                        "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']),
-                                                        getattr(config.alert_config, 'alert_value', ['JSON']))}
-                    })
+                elif category in per_category_count:
+                    count = per_category_count[category]
+                    if count > threshold:
+                        alerts.append({
+                            "alert_type": getattr(config.alert_config, 'alert_type', ['Default']),
+                            "alert_id": f"alert_{category}_{frame_key}",
+                            "incident_category": self.CASE_TYPE,
+                            "threshold_level": threshold,
+                            "ascending": get_trend(self._ascending_alert_list, lookback=900, threshold=0.8),
+                            "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']),
+                                                            getattr(config.alert_config, 'alert_value', ['JSON']))}
+                        })
         return alerts
 
     def _generate_incidents(self, counting_summary: Dict, alerts: List, config: VehicleMonitoringConfig,
@@ -261,7 +279,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
                     self.current_incident_end_timestamp = current_timestamp
             elif self.current_incident_end_timestamp != 'Incident still active' and self.current_incident_end_timestamp != 'N/A':
                 self.current_incident_end_timestamp = 'N/A'
-
+                
             if config.alert_config and config.alert_config.count_thresholds:
                 threshold = config.alert_config.count_thresholds.get("all", 15)
                 intensity = min(10.0, (total_detections / threshold) * 10)
@@ -275,6 +293,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
                     level = "medium"
                     self._ascending_alert_list.append(1)
                 else:
+                    level = "low"
                     self._ascending_alert_list.append(0)
             else:
                 if total_detections > 30:
@@ -325,11 +344,10 @@ class VehicleMonitoringUseCase(BaseProcessor):
         else:
             self._ascending_alert_list.append(0)
             incidents.append({})
-
         return incidents
 
     def _generate_tracking_stats(self, counting_summary: Dict, alerts: List, config: VehicleMonitoringConfig,
-                              frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[Dict]:
+                                frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[Dict]:
         camera_info = self.get_camera_info_from_stream(stream_info)
         tracking_stats = []
         total_detections = counting_summary.get("total_count", 0)
@@ -343,15 +361,19 @@ class VehicleMonitoringUseCase(BaseProcessor):
         total_counts = [{"category": cat, "count": count} for cat, count in total_counts_dict.items() if count > 0]
         current_counts = [{"category": cat, "count": count} for cat, count in per_category_count.items() if count > 0 or total_detections > 0]
 
-        detections = [
-            {
-                "category": detection.get("category"),
-                "bounding_box": detection.get("bounding_box", {}),
-                "masks": detection.get("masks", []) if detection.get("masks") else None,
-                "segmentation": detection.get("segmentation") if detection.get("segmentation") else None,
-                "mask": detection.get("mask") if detection.get("mask") else None
-            } for detection in counting_summary.get("detections", [])
-        ]
+        detections = []
+        for detection in counting_summary.get("detections", []):
+            bbox = detection.get("bounding_box", {})
+            category = detection.get("category", "vehicle")
+            if detection.get("masks"):
+                detection_obj = self.create_detection_object(category, bbox, segmentation=detection.get("masks"))
+            elif detection.get("segmentation"):
+                detection_obj = self.create_detection_object(category, bbox, segmentation=detection.get("segmentation"))
+            elif detection.get("mask"):
+                detection_obj = self.create_detection_object(category, bbox, segmentation=detection.get("mask"))
+            else:
+                detection_obj = self.create_detection_object(category, bbox)
+            detections.append(detection_obj)
 
         alert_settings = []
         if config.alert_config and hasattr(config.alert_config, 'alert_type'):
@@ -372,7 +394,11 @@ class VehicleMonitoringUseCase(BaseProcessor):
         for cat, count in total_counts_dict.items():
             if count > 0:
                 human_text_lines.append(f"\t{self.CATEGORY_DISPLAY.get(cat, cat)}: {count}")
-        human_text_lines.append(f"Alerts: {alerts[0].get('settings', {})} sent @ {current_timestamp}" if alerts else "Alerts: None")
+        if alerts:
+            for alert in alerts:
+                human_text_lines.append(f"Alerts: {alert.get('settings', {})} sent @ {current_timestamp}")
+        else:
+            human_text_lines.append("Alerts: None")
         human_text = "\n".join(human_text_lines)
 
         reset_settings = [{"interval_type": "daily", "reset_time": {"value": 9, "time_unit": "hour"}}]
@@ -392,8 +418,8 @@ class VehicleMonitoringUseCase(BaseProcessor):
         return tracking_stats
 
     def _generate_business_analytics(self, counting_summary: Dict, alerts: List, config: VehicleMonitoringConfig,
-                                  frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None,
-                                  is_empty=False) -> List[Dict]:
+                                    frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None,
+                                    is_empty=False) -> List[Dict]:
         if is_empty:
             return []
         # Implement business analytics if needed
@@ -414,7 +440,11 @@ class VehicleMonitoringUseCase(BaseProcessor):
         return [lines]
 
     def _get_track_ids_info(self, detections: list) -> Dict[str, Any]:
-        frame_track_ids = {det.get('track_id') for det in detections if det.get('track_id') is not None}
+        frame_track_ids = set()
+        for det in detections:
+            tid = det.get('track_id')
+            if tid is not None:
+                frame_track_ids.add(tid)
         total_track_ids = set()
         for s in getattr(self, '_per_category_total_track_ids', {}).values():
             total_track_ids.update(s)
@@ -522,7 +552,8 @@ class VehicleMonitoringUseCase(BaseProcessor):
                     "confidence": det.get("confidence"),
                     "track_id": det.get("track_id"),
                     "frame_id": det.get("frame_id")
-                } for det in detections
+                }
+                for det in detections
             ]
         }
 
@@ -532,7 +563,8 @@ class VehicleMonitoringUseCase(BaseProcessor):
                 "category": det.get("category", "unknown"),
                 "confidence": det.get("confidence", 0.0),
                 "bounding_box": det.get("bounding_box", {})
-            } for det in detections
+            }
+            for det in detections
         ]
 
     def _compute_iou(self, box1: Any, box2: Any) -> float:
