@@ -100,6 +100,11 @@ class WeaponDetectionUseCase(BaseProcessor):
             processed_data = [d for d in processed_data if d.get('category') in self.target_categories]
             self.logger.debug("Applied category filtering")
 
+        # Alert for detected weapons
+        for detection in processed_data:
+            if detection.get('category') in config.target_weapon_categories:
+                self.logger.warning(f"ALERT: {detection.get('category')} detected at {self._get_current_timestamp_str(stream_info)}")
+
         if config.enable_smoothing:
             if self.smoothing_tracker is None:
                 smoothing_config = BBoxSmoothingConfig(
@@ -239,7 +244,7 @@ class WeaponDetectionUseCase(BaseProcessor):
                 self.current_incident_end_timestamp = 'N/A'
 
             if config.alert_config and config.alert_config.count_thresholds:
-                threshold = config.alert_config.count_thresholds.get("all", 15)
+                threshold = config.alert_config.count_thresholds.get("all", 1)
                 intensity = min(10.0, (total_detections / threshold) * 10)
                 if intensity >= 9:
                     level = "critical"
@@ -330,15 +335,23 @@ class WeaponDetectionUseCase(BaseProcessor):
                 "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']),
                                                 getattr(config.alert_config, 'alert_value', ['JSON']))}
             })
+        weapon_counts = {cat: per_category_count.get(cat, 0) for cat in config.target_weapon_categories}
 
         human_text_lines = [f"Tracking Statistics:"]
         human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}")
-        for cat, count in per_category_count.items():
-            human_text_lines.append(f"\t{cat}: {count}")
+        if any(count > 0 for count in weapon_counts.values()):
+            for cat, count in weapon_counts.items():
+                if count > 0:
+                    human_text_lines.append(f"\t- {count} {cat.capitalize()} incident(s) detected")
+        else:
+            human_text_lines.append(f"\t- No weapon[s] detected")
+
+        human_text_lines.append("")
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}")
         for cat, count in total_counts_dict.items():
             if count > 0:
-                human_text_lines.append(f"\t{cat}: {count}")
+                human_text_lines.append(f"\t{count} {cat} [s] Detected")
+        human_text_lines.append("")
         human_text_lines.append("Alerts: None" if not alerts else f"Alerts: {alerts[0].get('settings', {})} sent @ {current_timestamp}")
         human_text = "\n".join(human_text_lines)
 
